@@ -1,15 +1,28 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "soundtest.h"
-#include "addressee.h"
 #include "kcontacts/sound.h"
-#include "vcardtool_p.h"
-#include <QTest>
+#include "addressee.h"
+#include <qtest.h>
+#include "vcardtool.h"
 
 QTEST_MAIN(SoundTest)
 
@@ -55,8 +68,7 @@ void SoundTest::storeTestExtern()
 
 void SoundTest::equalsTestIntern()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setData(testData());
     sound2.setData(testData());
@@ -66,8 +78,7 @@ void SoundTest::equalsTestIntern()
 
 void SoundTest::equalsTestExtern()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setUrl(QStringLiteral("http://myhomepage.com/sound.wav"));
     sound2.setUrl(QStringLiteral("http://myhomepage.com/sound.wav"));
@@ -77,8 +88,7 @@ void SoundTest::equalsTestExtern()
 
 void SoundTest::differsTest()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setUrl(QStringLiteral("http://myhomepage.com/sound.wav"));
     sound2.setData(testData());
@@ -88,8 +98,7 @@ void SoundTest::differsTest()
 
 void SoundTest::assignmentTestIntern()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setData(testData());
 
@@ -100,8 +109,7 @@ void SoundTest::assignmentTestIntern()
 
 void SoundTest::assignmentTestExtern()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setUrl(QStringLiteral("http://myhomepage.com/sound.wav"));
 
@@ -112,8 +120,7 @@ void SoundTest::assignmentTestExtern()
 
 void SoundTest::serializeTest()
 {
-    KContacts::Sound sound1;
-    KContacts::Sound sound2;
+    KContacts::Sound sound1, sound2;
 
     sound1.setUrl(QStringLiteral("http://myhomepage.com/sound.wav"));
     sound1.setData(testData());
@@ -130,15 +137,14 @@ void SoundTest::serializeTest()
 
 void SoundTest::shouldParseSource()
 {
-    QByteArray vcarddata(
-        "BEGIN:VCARD\n"
-        "VERSION:3.0\n"
-        "N:LastName;FirstName;;;\n"
-        "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
-        "REV:2015-03-14T09:24:45+00:00\n"
-        "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\n"
-        "FN:FirstName LastName\n"
-        "END:VCARD\n");
+    QByteArray vcarddata("BEGIN:VCARD\n"
+                         "VERSION:3.0\n"
+                         "N:LastName;FirstName;;;\n"
+                         "UID:c80cf296-0825-4eb0-ab16-1fac1d522a33@xxxxxx.xx\n"
+                         "REV:2015-03-14T09:24:45+00:00\n"
+                         "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\n"
+                         "FN:FirstName LastName\n"
+                         "END:VCARD\n");
 
     KContacts::VCardTool vcard;
     const KContacts::AddresseeList lst = vcard.parseVCards(vcarddata);
@@ -165,14 +171,13 @@ void SoundTest::shouldGenerateVCard4WithData()
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
     QByteArray expected;
-    expected = QByteArray(
-        "BEGIN:VCARD\r\n"
-        "VERSION:4.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "SOUND;ENCODING=b:AAECAwQFBgcICQoLDA0ODxAREhM=\r\n"
-        "UID:testuid\r\n"
-        "END:VCARD\r\n\r\n");
+    expected = QByteArray("BEGIN:VCARD\r\n"
+                          "VERSION:4.0\r\n"
+                          "EMAIL:foo@kde.org\r\n"
+                          "N:;;;;\r\n"
+                          "SOUND;ENCODING=b:AAECAwQFBgcICQoLDA0ODxAREhM=\r\n"
+                          "UID:testuid\r\n"
+                          "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
 }
@@ -192,14 +197,13 @@ void SoundTest::shouldGenerateVCard4WithUrl()
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v4_0);
     QByteArray expected;
-    expected = QByteArray(
-        "BEGIN:VCARD\r\n"
-        "VERSION:4.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\r\n"
-        "UID:testuid\r\n"
-        "END:VCARD\r\n\r\n");
+    expected = QByteArray("BEGIN:VCARD\r\n"
+                          "VERSION:4.0\r\n"
+                          "EMAIL:foo@kde.org\r\n"
+                          "N:;;;;\r\n"
+                          "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\r\n"
+                          "UID:testuid\r\n"
+                          "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
 }
@@ -220,14 +224,13 @@ void SoundTest::shouldGenerateVCard3WithData()
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v3_0);
     QByteArray expected;
-    expected = QByteArray(
-        "BEGIN:VCARD\r\n"
-        "VERSION:3.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "SOUND;ENCODING=b:AAECAwQFBgcICQoLDA0ODxAREhM=\r\n"
-        "UID:testuid\r\n"
-        "END:VCARD\r\n\r\n");
+    expected = QByteArray("BEGIN:VCARD\r\n"
+                          "VERSION:3.0\r\n"
+                          "EMAIL:foo@kde.org\r\n"
+                          "N:;;;;\r\n"
+                          "SOUND;ENCODING=b:AAECAwQFBgcICQoLDA0ODxAREhM=\r\n"
+                          "UID:testuid\r\n"
+                          "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
 }
@@ -247,16 +250,13 @@ void SoundTest::shouldGenerateVCard3WithUrl()
     KContacts::VCardTool vcard;
     const QByteArray ba = vcard.exportVCards(lst, KContacts::VCard::v3_0);
     QByteArray expected;
-    expected = QByteArray(
-        "BEGIN:VCARD\r\n"
-        "VERSION:3.0\r\n"
-        "EMAIL:foo@kde.org\r\n"
-        "N:;;;;\r\n"
-        "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\r\n"
-        "UID:testuid\r\n"
-        "END:VCARD\r\n\r\n");
+    expected = QByteArray("BEGIN:VCARD\r\n"
+                          "VERSION:3.0\r\n"
+                          "EMAIL:foo@kde.org\r\n"
+                          "N:;;;;\r\n"
+                          "SOUND;VALUE=URI:http://myhomepage.com/sound.wav\r\n"
+                          "UID:testuid\r\n"
+                          "END:VCARD\r\n\r\n");
 
     QCOMPARE(ba, expected);
 }
-
-#include "moc_soundtest.cpp"
